IKunIlpExtractor

Struct IKunIlpExtractor 

pub struct IKunIlpExtractor<'a, A: Analysis<IKun>, C: CostModel> {
    pub egraph: &'a EGraph<IKun, A>,
    pub cost_model: C,
}
A DAG-aware extractor that attempts to find the optimal extraction considering node sharing. This is a placeholder for a full ILP solver.

Fields

egraph: &'a EGraph<IKun, A>cost_model: C

Implementations

Source

impl<'a, A: Analysis<IKun>, C: CostModel + Clone> IKunIlpExtractor<'a, A, C>

pub fn new(egraph: &'a EGraph<IKun, A>, cost_model: C) -> Self

pub fn extract(&self, id: Id) -> IKunTree
where A::Data: HasDebugInfo,

Performs extraction. Currently uses the greedy extractor as a fallback. In a full implementation, this would use an ILP solver to find the minimum cost subgraph that covers the root e-class.